@@ -5,6 +5,7 @@
 
 extern crate typemap;
 use typemap::{TypeMap, Key};
+use std::any::Any;
 
 /// Implementers of this trait can act as plugins for other types, via `OtherType::get<P>()`.
 ///
@@ -45,7 +46,7 @@ pub trait Pluggable {
     ///
     /// `P` is the plugin type.
     fn get<P: Plugin<Self>>(&mut self) -> Result<P::Value, P::Error>
-    where P::Value: Clone + 'static, Self: Extensible, P::Error: Clone {
+    where P::Value: Clone + Any, Self: Extensible, P::Error: Clone {
         self.get_ref::<P>().map(|v| v.clone())
     }
 
@@ -56,7 +57,7 @@ pub trait Pluggable {
     ///
     /// `P` is the plugin type.
     fn get_ref<P: Plugin<Self>>(&mut self) -> Result<&P::Value, P::Error>
-    where P::Value: 'static, Self: Extensible {
+    where P::Value: Any, Self: Extensible {
         self.get_mut::<P>().map(|mutref| &*mutref)
     }
 
@@ -67,7 +68,7 @@ pub trait Pluggable {
     ///
     /// `P` is the plugin type.
     fn get_mut<P: Plugin<Self>>(&mut self) -> Result<&mut P::Value, P::Error>
-    where P::Value: 'static, Self: Extensible {
+    where P::Value: Any, Self: Extensible {
         use typemap::Entry::{Occupied, Vacant};
         use std::intrinsics::unreachable;
 
@@ -75,7 +76,7 @@ pub trait Pluggable {
             return Ok(self.extensions_mut().get_mut::<P>().unwrap());
         }
 
-        <P as Plugin<Self>>::eval(self).map(move |data| {
+        P::eval(self).map(move |data| {
             match self.extensions_mut().entry::<P>() {
                 Vacant(entry) => entry.insert(data),
                 Occupied(..) => unsafe { unreachable() }
@@ -93,7 +94,7 @@ pub trait Pluggable {
 mod test {
     extern crate void;
 
-    use test::void::{Void, VoidExtensions};
+    use test::void::{Void, ResultVoidExt};
 
     use typemap::{TypeMap, Key};
     use super::{Extensible, Plugin, Pluggable};
